Crate duped

Crate duped 

This library can be used to find duplicated files starting from a particular root directory. To use it, please look over the following docs: find, Params, and Stats.

Examples

use file_duplicates::{find, Params};

let params = Params::new(0, vec!["./".into()], "test.db".into());
let stats = find(&params).unwrap();

Structs

Entry
HashDb
A sqlite database which stores Entrys.
Params
Used to configure the find function.
Stats
Useful stats about a successful find operation.

Functions

find
Finds and returns duplicated files on disk.

Type Aliases

Duplicates